# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pango_collapse']

package_data = \
{'': ['*']}

install_requires = \
['numpy>=1.21,<=1.23.2',
 'pandas>=1.3,<=1.4.4',
 'pango-aliasor>=0.2.0,<0.3.0',
 'typer[all]>=0.6.1,<0.7.0']

entry_points = \
{'console_scripts': ['pango-collapse = pango_collapse.main:app']}

setup_kwargs = {
    'name': 'pango-collapse',
    'version': '0.5.0',
    'description': '',
    'long_description': '# Pango-collapse \n\n[![](https://img.shields.io/pypi/v/pango-collapse.svg)](https://pypi.org/project/pango-collapse/)\n[![tests](https://github.com/MDU-PHL/pango-collapse/actions/workflows/tests.yaml/badge.svg)](https://github.com/MDU-PHL/pango-collapse/actions/workflows/tests.yaml)\n\nCLI to collapse Pango linages for reporting\n\n[![](images/collapse.gif)](https://mdu-phl.github.io/pango-watch/tree/)\n\n## Install \n\nInstall from pypi with pip.\n\n```\npip install pango-collapse\n```\n\n## Usage\n\n`pango-collapse` takes a CSV file of SARS-CoV-2 samples (`input.csv`) with a column (default `Lineage`) indicating the pango lineage of the samples (e.g. output from pangoLEARN, nextclade, USHER, etc). \n\n```\n# input.csv\nLineage\nBA.5.2.1\nBA.4.6\nBE.1\n```\n\n`pango-collapse` will collapse lineages up to the first user defined parent lineage (specified in a text file with `--collapse-file`). If the sample lineage has no parent lineage in the user defined collapse file the compressed lineage will be returned. Collapse up to either `A` or `B` by adding A and B to the collapse file. By default (i.e. if no collapse file is specified) `pango-collapse` uses the collapse file found [here](https://github.com/MDU-PHL/pango-collapse/blob/main/pango_collapse/collapse.txt). This file is dependant on the version of `pango-collapse`, use `--latest` to load the latest version of the collapse file from github at run time. \n\n```\n# collapse.txt\nBA.5\nBE.1\n```\n\n`pango-collapse` will produce an output file which is a copy of the input file plus `Lineage_full` (the uncompressed lineage) and `Lineage_family` (the lineage compressed up to) columns. \n\n\n```bash\npango-collapse input.csv --collapse-file collapse.txt -o output.csv \n```\n\n```\n# output.csv \nLineage,Lineage_full,Lineage_family\nBA.5.2.1,B.1.1.529.5.2.1,BA.5\nBA.4.6,B.1.1.529.4.6,BA.4.6\nBE.1,B.1.1.529.5.3.1.1,BE.1\n```\n\n## Nextclade example\n\nThis example shows how to use some of the `pango-collapse` features by collapsing the Pango Lineages in the output from [Nextclade](https://clades.nextstrain.org/).\n\nProduce a nextclade.tsv file from a `nextclade` analysis (there is an example file in [`tests/data`](https://github.com/MDU-PHL/pango-collapse/tree/main/tests/data)). \n\nWe are only interested in the major sub-lineages of omicron i.e. BA.1-BA.5. We can therefor make a collapse file with the following:\n\n```\n# omicron\nBA.1\nBA.2\nBA.3\nBA.4\nBA.5\n```\n\n> Note: BA is an alias of B.1.1.529, however, as we have not included B.1.1.529 in our collapse file any samples designated B.1.1.529 will not be compressed.\n\nRun the following command to collapse the omicron sub-lineages:\n\n```\npango-collapse nextclade.tsv -o nextclade_collapsed_omicron.tsv -l Nextclade_pango --strict \n```\n\nThe `-l` (`--lineage-column`) flag tells `pango-collapse` to look for the compressed linage in the `Nextclade_pango` column in the nextclade.tsv file.\n\nThe `--strict` tells `pango-collapse` to use strict mode i.e. only report lineages in the collapse file. If the lineage cannot be collapsed then no value is returned in the collapse column. \n\nWe can visualise the results in pandas:\n\n```python\nimport pandas as pd\ndf = pd.read_csv("nextclade_output.tsv", sep="\\t")\ndf.Lineage_family.fillna(\'Other\', inplace=True)\ndf.Lineage_family.value_counts().plot(kind=\'bar\')\n```\n\n![](images/nextclade_omicron.jpg)\n\n## --help\n\n```\n                                                                       \n Usage: pango-collapse [OPTIONS] INPUT                                  \n                                                                        \n Collapse Pango sublineages up to user defined parent lineages.         \n                                                                        \n╭─ Arguments ──────────────────────────────────────────────────────────╮\n│ *    input      FILE  Path to input CSV/TSV with Lineage column.     │\n│                       [default: None]                                │\n│                       [required]                                     │\n╰──────────────────────────────────────────────────────────────────────╯\n╭─ Options ────────────────────────────────────────────────────────────╮\n│ *  --output              -o      FILE  Path to output CSV/TSV with   │\n│                                        Lineage column.               │\n│                                        [default: None]               │\n│                                        [required]                    │\n│    --collapse-file       -c      PATH  Path to collapse file with    │\n│                                        lineages (one per line) to    │\n│                                        collapse up to. Defaults to   │\n│                                        collapse file shipped with    │\n│                                        this version of               │\n│                                        pango-collapse.               │\n│                                        [default:                     │\n│                                        /Users/wwirth/Library/CloudS… │\n│    --lineage-column      -l      TEXT  Column to extract from input  │\n│                                        file for lineage.             │\n│                                        [default: Lineage]            │\n│    --full-column         -f      TEXT  Column to use for the         │\n│                                        uncompressed output.          │\n│                                        [default: Lineage_full]       │\n│    --collapse-column     -k      TEXT  Column to use for the         │\n│                                        collapsed output.             │\n│                                        [default: Lineage_family]     │\n│    --alias-file          -a      PATH  Path to Pango Alias file for  │\n│                                        pango_aliasor. Will download  │\n│                                        latest file if not supplied.  │\n│                                        [default: None]               │\n│    --strict              -s            If a lineage is not in the    │\n│                                        collapse file return None     │\n│                                        instead of the uncompressed   │\n│                                        lineage.                      │\n│    --latest              -u            Use the latest collapse file  │\n│                                        from github.                  │\n│    --version             -v            Print the current version     │\n│                                        number and exit.              │\n│    --install-completion                Install completion for the    │\n│                                        current shell.                │\n│    --show-completion                   Show completion for the       │\n│                                        current shell, to copy it or  │\n│                                        customize the installation.   │\n│    --help                -h            Show this message and exit.   │\n╰──────────────────────────────────────────────────────────────────────╯\n```\n',
    'author': 'wytamma',
    'author_email': 'wytamma.wirth@me.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
